Learn R Programming

dropR (version 1.0.6)

do_print: Print dropout / test results in a compact, report-ready string

Description

Print dropout / test results in a compact, report-ready string

Usage

do_print(x, ..., as_markdown = FALSE, print = FALSE)

# S3 method for do_stats do_print( x, as_markdown = FALSE, item = NULL, conditions = NULL, digits_pct = 1, ... )

# S3 method for do_chi do_print(x, as_markdown = FALSE, digits_pct = 1, digits_stat = 2, ...)

Value

Summary of the input object as either a string, markdown-ready or console output.

Arguments

x

An object of class do_chisq (from do_chisq).

...

Additional arguments.

as_markdown

Boolean. Should the output be formatted for a Markdown document (e.g. Quarto)? Defaults to FALSE.

print

Boolean. Should the output be formatted for printing (e.g. to store in a character vector)? Defaults to FALSE.

item

Numeric item index. Default NULL = last item for do_stats.

conditions

Optional vector of conditions to include (ignored for totals unless you include them).

digits_pct

Digits for percentages.

digits_stat

Digits for test statistic.

Examples

Run this code
do_stats <- compute_stats(df = add_dropout_idx(dropRdemo, 3:54),
by_cond = "experimental_condition",
no_of_vars = 52)

do_print(do_stats)

Run the code above in your browser using DataLab