powered by
Print dropout / test results in a compact, report-ready string
do_print(x, ..., as_markdown = FALSE, print = FALSE)# S3 method for do_stats do_print( x, as_markdown = FALSE, item = NULL, conditions = NULL, digits_pct = 1, ... )# S3 method for do_chi do_print(x, as_markdown = FALSE, digits_pct = 1, digits_stat = 2, ...)
# S3 method for do_stats do_print( x, as_markdown = FALSE, item = NULL, conditions = NULL, digits_pct = 1, ... )
# S3 method for do_chi do_print(x, as_markdown = FALSE, digits_pct = 1, digits_stat = 2, ...)
Summary of the input object as either a string, markdown-ready or console output.
An object of class do_chisq (from do_chisq).
do_chisq
Additional arguments.
Boolean. Should the output be formatted for a Markdown document (e.g. Quarto)? Defaults to FALSE.
Boolean. Should the output be formatted for printing (e.g. to store in a character vector)? Defaults to FALSE.
Numeric item index. Default NULL = last item for do_stats.
Optional vector of conditions to include (ignored for totals unless you include them).
Digits for percentages.
Digits for test statistic.
do_stats <- compute_stats(df = add_dropout_idx(dropRdemo, 3:54), by_cond = "experimental_condition", no_of_vars = 52) do_print(do_stats)
Run the code above in your browser using DataLab