Analysis and visualization of dropout between conditions in surveys and (online) experiments. Features include computation of dropout statistics, comparing dropout between conditions (e.g. Chi squared), analyzing survival (e.g. Kaplan-Meier estimation), comparing conditions with the most different rates of dropout (Kolmogorov-Smirnov) and visualizing the result of each in designated plotting functions. Article published in _Behavior Research Methods_ on 'dropR' by the authors: Dropout analysis: A method for data from Internet-based research and 'dropR', an R-based web app and package to analyze and visualize dropout. (2025) tools:::Rd_expr_doi("10.3758/s13428-025-02730-2"). Sources: Andrea Frick, Marie-Terese Baechtiger & Ulf-Dietrich Reips (2001) tools:::Rd_expr_doi("10.5167/uzh-19758"); Ulf-Dietrich Reips (2002) tools:::Rd_expr_doi("10.1027//1618-3169.49.4.243").
Maintainer: Annika Tave Overlander annika-tave.overlander@uni.kn (ORCID)
Authors:
Matthias Bannert bannert@kof.ethz.ch
Ulf-Dietrich Reips (ORCID)